@@ -111,8 +111,15 @@ check_round_trip <- function(x, styled_code, data, check, compare, caller) {
   evaled <- try_eval(styled_code, data, check, caller)
   if (missing(evaled) || (is.null(evaled) && !is.null(x))) return(NULL)
 
+  if (compare$ignore_srcref) {
+    rlang::local_bindings(
+      compare_proxy.S7_object = compare_proxy_S7_object,
+      .env = .GlobalEnv
+    )
+  }
   # set custom method for waldo
   rlang::local_bindings(
+    compare_proxy.LayerInstance = compare_proxy_LayerInstance,
     compare_proxy.ggplot = compare_proxy_ggplot,
     compare_proxy.weakref = compare_proxy_weakref,
     compare_proxy.R6ClassGenerator = compare_proxy_R6ClassGenerator,
@@ -131,6 +138,10 @@ check_round_trip <- function(x, styled_code, data, check, compare, caller) {
       max_diffs = Inf
     )
 
+  # special case ggplot2 NSE artifacts
+  max_diffs <- attr(issues, "max_diffs")
+  issues <- issues[!detect_ggplot_nse_artifacts(issues)]
+  attr(issues, "max_diffs") <- max_diffs
   # return early if no issue
   if (!length(issues)) return(NULL)
 
@@ -149,6 +160,14 @@ check_round_trip <- function(x, styled_code, data, check, compare, caller) {
   issues
 }
 
+detect_ggplot_nse_artifacts <- function(issues) {
+  # concatenate multiline
+  issues <- gsub("`\033\\[39m +\033\\[32m` +", "", issues)
+  # detect errors that are the same except for a `ggplot2::` prefix
+  cli::ansi_grepl("^(.*?)original(.*?): *`(.*?)` +\n\\1recreated\\2: *`(ggplot2::\\3)`", issues)
+}
+
+
 new_constructive <- function(code, compare) {
   structure(list(code = code, compare = compare), class = "constructive")
 }
@@ -218,6 +237,7 @@ all_classes <- list(
     "list",
     "logical",
     "NULL",
+    "object",
     "pairlist",
     "raw",
     "S4",
@@ -266,6 +286,16 @@ all_classes <- list(
   blob = c(
     "blob"
   ),
+  constructive = c(
+    "constructive_options"
+  ),
+  ellmer = c(
+    "ellmer::TypeArray",
+    "ellmer::TypeBasic", 
+    "ellmer::TypeEnum", 
+    "ellmer::TypeJsonSchema",
+    "ellmer::TypeObject"
+  ),
   ggplot2 = c(
     "CoordCartesian",
     "CoordFixed",
@@ -274,17 +304,45 @@ all_classes <- list(
     "CoordMunch",
     "CoordPolar",
     "CoordQuickmap",
+    "CoordRadial",
     "CoordSf",
     "CoordTrans",
+    "CoordTransform",
     "element_blank",
     "element_grob",
     "element_line",
     "element_rect",
     "element_render",
     "element_text",
+    "FacetGrid",
+    "FacetNull",
     "FacetWrap",
     "ggplot",
+    "ggplot2::element_blank",
+    "ggplot2::element_geom",
+    "ggplot2::element_line",
+    "ggplot2::element_point",
+    "ggplot2::element_polygon",
+    "ggplot2::element_rect",
+    "ggplot2::element_text",
+    "ggplot2::ggplot",
+    "ggplot2::labels",
+    "ggplot2::mapping",
+    "ggplot2::margin",
+    "ggplot2::theme",
     "ggproto",
+    "Guide",
+    "GuideAxis",
+    "GuideAxisLogticks",
+    "GuideAxisStack",
+    "GuideAxisTheta",
+    "GuideBins",
+    "GuideColourbar",
+    "GuideColoursteps",
+    "GuideCustom",
+    "GuideLegend",
+    "GuideNone",
+    "Guides",
     "labels",
     "Layer",
     "margin",
@@ -304,10 +362,38 @@ all_classes <- list(
   grid = c(
     "simpleUnit"
   ),
+  R6 = c(
+    "R6",
+    "R6ClassGenerator"
+  ),
   rlang = c(
     "quosure",
     "quosures"
   ),
-  tibble = c("tbl_df"),
-  vctrs = c("vctrs_list_of")
+  S7 = c(
+    "S7_any", 
+    "S7_base_class", 
+    "S7_class",
+    "S7_external_generic",
+    "S7_generic", 
+    "S7_object", 
+    "S7_property",
+    "S7_S3_class", 
+    "S7_union"
+  ),
+  tibble = c(
+    "tbl_df"
+  ),
+  vctrs = c(
+    "vctrs_list_of"
+  ),
+  xts = c(
+    "xts"
+  ),
+  zoo = c(
+    "yearmon",
+    "yearqtr",
+    "zoo",
+    "zooreg"
+  )
 )
