@@ -1,5 +1,5 @@
 test_that("rowwise_df", {
-  expect_pipe_snapshot({
+  expect_snapshot({
     construct(dplyr::rowwise(head(cars,2)))
     construct(dplyr::rowwise(head(cars,2), dist))
   })
